@@ -2,10 +2,12 @@ from . import (
     rev0,
     rev1,
     rev2,
+    rev3,
 )
 
 revisions = {
     0: rev0,
     1: rev1,
     2: rev2,
+    3: rev3,
 }
